package com.huimv.environment.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.dynamic.datasource.annotation.DS;
import com.huimv.common.date.DateUtil;
import com.huimv.common.result.Result;
import com.huimv.common.result.ResultCode;
import com.huimv.environment.entity.*;
import com.huimv.environment.repo.*;
import com.huimv.environment.service.IEnvironmentControlService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * @Project : huimv.shiwan
 * @Package : com.huimv.biosafety.uface.controller
 * @Description : TODO
 * @Version : 1.0
 * @Author : ZhuoNing
 * @Create : 2020-12-25
 **/
@Service
public class EnvironmentControlServiceImpl implements IEnvironmentControlService {
    @Autowired
    private BasePigpenRepo basePigpenRepo;
    @Autowired
    private BaseColumnPeriodRepo baseColumnPeriodRepo;
    @Autowired
    private SjHkAqRepo aqRepo;
    @Autowired
    private SjHkSdRepo sdRepo;
    @Autowired
    private SjHkWdRepo wdRepo;

    @Override
    public Result getPigpenByFarm(Integer farmId) {
        //--读取所有猪舍
        List<BasePigpenEntity> zsdsList = basePigpenRepo.getAllPigpen(farmId);
//        System.out.println("zsdsList.size>>"+zsdsList.size());
        if (zsdsList.size() == 0) {
            //返回出错
            return new Result(10001, "牧场id(" + farmId + ")中的猪舍为0", false);
        }
        List zsidList = new ArrayList();
        for (BasePigpenEntity zsdaEntity : zsdsList) {
            zsidList.add(zsdaEntity.getID());
        }
//        System.out.println("zsSb>>"+zsidList.toString());
        //--读取所有栏期
        List<BaseColumnPeriodEntity> lqdaEntityList = baseColumnPeriodRepo.getLqid(zsidList);
//        System.out.println("栏期length>>"+lqdaEntityList.size());
        if (lqdaEntityList.size() == 0) {
            //返回出错.
            return new Result(10002, "这个牧场(" + farmId + ")中的猪舍暂无相关任何栏期", false);
        }
        List lqidList = new ArrayList();
//        for (DaLqdaEntity lqdaEntity : lqdaEntityList) {
//            lqidList.add(lqdaEntity.getID());
//        }
//        System.out.println("lqidList>>"+lqidList.toString());
        JSONArray zsJa = new JSONArray();
        for (BasePigpenEntity zsdaEntity : zsdsList) {
            int zsid = zsdaEntity.getID();
            JSONObject zsJo = new JSONObject();
            zsJa.add(zsJo);
            zsJo.put("zsid", zsid);
            zsJo.put("zsmc", zsdaEntity.getZSMC());
            for (BaseColumnPeriodEntity lqdaEntity : lqdaEntityList) {
                if (lqdaEntity.getZSID() == zsid) {
                    zsJo.put("lqid", lqdaEntity.getID());
                    break;
                }
            }
        }
        return new Result(ResultCode.SUCCESS, zsJa);
    }

    @Override
//    @DS("master")
    public Result getLastEnvData(Integer lqid) {
        String todayDate = new DateUtil().formatDate(new Date());
        System.out.println(" todayDate>>"+todayDate);
        System.out.println(" lqid>>"+lqid);
        JSONObject envJo = new JSONObject();
        envJo.put("lqid",lqid);
        //--读取最新氨气
        SjHkAqEntity aqEntity = aqRepo.getLastAq(lqid, todayDate);
        System.out.println("aqEntity>>" + aqEntity);
        if (aqEntity != null) {
            envJo.put("ammonia", aqEntity.getDQAQ());
        } else {
            envJo.put("ammonia", "");
        }
        //--读取最新湿度
        SjHkSdEntity sdEntity = sdRepo.getLastSd(lqid, todayDate);
        if (sdEntity != null) {
            envJo.put("humidity", sdEntity.getDQSD());
        } else {
            envJo.put("humidity", "");
        }
        //--读取最新温度
        SjHkWdEntity wdEntity = wdRepo.getLastWd(lqid, todayDate);
        if (wdEntity != null) {
            envJo.put("temp", wdEntity.getDQWD());
        } else {
            envJo.put("temp", "");
        }
        return new Result(ResultCode.SUCCESS, envJo);
    }
}
